# Form implementation generated from reading ui file './data_overview_table_widget.ui'
#
# Created by: PyQt6 UI code generator 6.8.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_DataOverviewTableWidget(object):
    def setupUi(self, DataOverviewTableWidget):
        DataOverviewTableWidget.setObjectName("DataOverviewTableWidget")
        DataOverviewTableWidget.resize(458, 407)
        self.horizontalLayout = QtWidgets.QHBoxLayout(DataOverviewTableWidget)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.tableView = QtWidgets.QTableView(parent=DataOverviewTableWidget)
        self.tableView.setObjectName("tableView")
        self.horizontalLayout.addWidget(self.tableView)

        self.retranslateUi(DataOverviewTableWidget)
        QtCore.QMetaObject.connectSlotsByName(DataOverviewTableWidget)

    def retranslateUi(self, DataOverviewTableWidget):
        _translate = QtCore.QCoreApplication.translate
        DataOverviewTableWidget.setWindowTitle(_translate("DataOverviewTableWidget", "Form"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    DataOverviewTableWidget = QtWidgets.QWidget()
    ui = Ui_DataOverviewTableWidget()
    ui.setupUi(DataOverviewTableWidget)
    DataOverviewTableWidget.show()
    sys.exit(app.exec())
