# Form implementation generated from reading ui file './data_widget.ui'
#
# Created by: PyQt6 UI code generator 6.8.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_DataWidget(object):
    def setupUi(self, DataWidget):
        DataWidget.setObjectName("DataWidget")
        DataWidget.resize(331, 519)
        self.verticalLayout = QtWidgets.QVBoxLayout(DataWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.select_api_pushButton = QtWidgets.QPushButton(parent=DataWidget)
        self.select_api_pushButton.setObjectName("select_api_pushButton")
        self.horizontalLayout_4.addWidget(self.select_api_pushButton)
        self.open_txt_directory_pushButton = QtWidgets.QPushButton(parent=DataWidget)
        self.open_txt_directory_pushButton.setObjectName("open_txt_directory_pushButton")
        self.horizontalLayout_4.addWidget(self.open_txt_directory_pushButton)
        self.select_output_directory_pushButton = QtWidgets.QPushButton(parent=DataWidget)
        self.select_output_directory_pushButton.setObjectName("select_output_directory_pushButton")
        self.horizontalLayout_4.addWidget(self.select_output_directory_pushButton)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(parent=DataWidget)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.google_sheetnames_comboBox = QtWidgets.QComboBox(parent=DataWidget)
        self.google_sheetnames_comboBox.setObjectName("google_sheetnames_comboBox")
        self.horizontalLayout_2.addWidget(self.google_sheetnames_comboBox)
        self.horizontalLayout_2.setStretch(0, 1)
        self.horizontalLayout_2.setStretch(1, 2)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_4 = QtWidgets.QLabel(parent=DataWidget)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_5.addWidget(self.label_4)
        self.files_in_directory_lineEdit = QtWidgets.QLineEdit(parent=DataWidget)
        self.files_in_directory_lineEdit.setObjectName("files_in_directory_lineEdit")
        self.horizontalLayout_5.addWidget(self.files_in_directory_lineEdit)
        self.horizontalLayout_5.setStretch(0, 1)
        self.horizontalLayout_5.setStretch(1, 2)
        self.verticalLayout.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_2 = QtWidgets.QLabel(parent=DataWidget)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_3.addWidget(self.label_2)
        self.filename_regex_lineEdit = QtWidgets.QLineEdit(parent=DataWidget)
        self.filename_regex_lineEdit.setObjectName("filename_regex_lineEdit")
        self.horizontalLayout_3.addWidget(self.filename_regex_lineEdit)
        self.horizontalLayout_3.setStretch(0, 1)
        self.horizontalLayout_3.setStretch(1, 2)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_6 = QtWidgets.QLabel(parent=DataWidget)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_7.addWidget(self.label_6)
        self.example_filename_lineEdit = QtWidgets.QLineEdit(parent=DataWidget)
        self.example_filename_lineEdit.setObjectName("example_filename_lineEdit")
        self.horizontalLayout_7.addWidget(self.example_filename_lineEdit)
        self.horizontalLayout_7.setStretch(0, 1)
        self.horizontalLayout_7.setStretch(1, 2)
        self.verticalLayout.addLayout(self.horizontalLayout_7)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_3 = QtWidgets.QLabel(parent=DataWidget)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout.addWidget(self.label_3)
        self.example_filename_id_lineEdit = QtWidgets.QLineEdit(parent=DataWidget)
        self.example_filename_id_lineEdit.setObjectName("example_filename_id_lineEdit")
        self.horizontalLayout.addWidget(self.example_filename_id_lineEdit)
        self.horizontalLayout.setStretch(0, 1)
        self.horizontalLayout.setStretch(1, 2)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_5 = QtWidgets.QLabel(parent=DataWidget)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_6.addWidget(self.label_5)
        self.google_lookup_column_comboBox = QtWidgets.QComboBox(parent=DataWidget)
        self.google_lookup_column_comboBox.setObjectName("google_lookup_column_comboBox")
        self.horizontalLayout_6.addWidget(self.google_lookup_column_comboBox)
        self.horizontalLayout_6.setStretch(0, 1)
        self.horizontalLayout_6.setStretch(1, 2)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_7 = QtWidgets.QLabel(parent=DataWidget)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_8.addWidget(self.label_7)
        self.google_lookup_id_lineEdit = QtWidgets.QLineEdit(parent=DataWidget)
        self.google_lookup_id_lineEdit.setObjectName("google_lookup_id_lineEdit")
        self.horizontalLayout_8.addWidget(self.google_lookup_id_lineEdit)
        self.horizontalLayout_8.setStretch(0, 1)
        self.horizontalLayout_8.setStretch(1, 2)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.generate_hdf5_pushButton = QtWidgets.QPushButton(parent=DataWidget)
        self.generate_hdf5_pushButton.setObjectName("generate_hdf5_pushButton")
        self.verticalLayout.addWidget(self.generate_hdf5_pushButton)
        self.logging_plainTextEdit = QtWidgets.QPlainTextEdit(parent=DataWidget)
        self.logging_plainTextEdit.setObjectName("logging_plainTextEdit")
        self.verticalLayout.addWidget(self.logging_plainTextEdit)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout.addItem(spacerItem)

        self.retranslateUi(DataWidget)
        QtCore.QMetaObject.connectSlotsByName(DataWidget)

    def retranslateUi(self, DataWidget):
        _translate = QtCore.QCoreApplication.translate
        DataWidget.setWindowTitle(_translate("DataWidget", "Form"))
        self.select_api_pushButton.setText(_translate("DataWidget", "Google API"))
        self.open_txt_directory_pushButton.setText(_translate("DataWidget", "Import From"))
        self.select_output_directory_pushButton.setText(_translate("DataWidget", "Write To"))
        self.label.setText(_translate("DataWidget", "Sheetname"))
        self.label_4.setText(_translate("DataWidget", "Files Found"))
        self.label_2.setText(_translate("DataWidget", "Regex"))
        self.label_6.setText(_translate("DataWidget", "Filename"))
        self.label_3.setText(_translate("DataWidget", "Filename ID"))
        self.label_5.setText(_translate("DataWidget", "ID Lookup Col"))
        self.label_7.setText(_translate("DataWidget", "Lookup ID"))
        self.generate_hdf5_pushButton.setText(_translate("DataWidget", "Create Dataset"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    DataWidget = QtWidgets.QWidget()
    ui = Ui_DataWidget()
    ui.setupUi(DataWidget)
    DataWidget.show()
    sys.exit(app.exec())
